# GPG Encrypt Decrypt GUI: gpged
> `gpged` is a QT6 python application that makes use of GnuPG to present a simple interface for basic pgp operations.

## Install with Pip from Pypi:  
`pip install gpged`
## Install with Pip from source:  
```bash
# clone the repo then
cd gpged
pip install .
```
## Install with pipenv from source:  
`pipenv install --system --deploy`
## Run gpged
`gpged`
### Nice UI  
![layout](https://github.com/skymoore/gpged/blob/main/gpged/images/layout.png?raw=true)
### Encrypt with multiple public keys  
![multi-key select](https://github.com/skymoore/gpged/blob/main/gpged/images/multi_key_select.png?raw=true)
### Decrypt messages  
![decypted message](https://github.com/skymoore/gpged/blob/main/gpged/images/decrypted_message.png?raw=true)